# 2021-07-21 - Liquidity Bootstrapping Pool

> ⚠️ **DEPRECATED: do not use** ⚠️
>
> This factory and associated Pools have been deprecated due to incorrect calculation of protocol fees when the global protocol swap fee percentage is non-zero. They have been [temporarily replaced with a version that addresses this](../../20211202-no-protocol-fee-lbp).

Deployment of the `LiquidityBootstrappingPoolFactory`, for Liquidity Bootstrapping Pools of up to 4 tokens.

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [Polygon mainnet addresses](./output/polygon.json)
- [Arbitrum mainnet address](./output/arbitrum.json)
- [Goerli testnet addresses](./output/goerli.json)
- [`LiquidityBootstrappingPoolFactory` artifact](./artifact/LiquidityBootstrappingPoolFactory.json)
